@@ -54,7 +54,7 @@ fn kernel_main(bootinfo: &'static BootInfo) -> !
 	let clonedref = refcounted.clone();
 	core::mem::drop(refcounted);
 
-	let bmpdat = include_bytes!("libraries/graphics/images/bmp/Logo-Dark.bmp");
+	let bmpdat = include_bytes!("../resources/images/bmp/Logo-Dark.bmp");
 
 	// This controls LibertyOS' text mode.
 	let textmode = Text80x25::new();
@@ -72,9 +72,14 @@ fn kernel_main(bootinfo: &'static BootInfo) -> !
 	graphicsmode.draw_line((540, 420), (540, 60), Color16::White);
 	graphicsmode.draw_line((80, 90), (540, 90), Color16::White);
 
-	for (offset, character) in "LibertyOS v0.12.0".chars().enumerate()
+	for (offset, character) in "LibertyOS v0.12.2".chars().enumerate()
 	{
-		graphicsmode.draw_character(270 + offset * 8, 72, character, Color16::Red)
+		graphicsmode.draw_character(250 + offset * 8, 72, character, Color16::Red)
+	}
+
+	for (offset, character) in "Welcome to LibertyOS.".chars().enumerate()
+	{
+		graphicsmode.draw_character(100 + offset * 8, 100, character, Color16::Yellow)
 	}
 
 	#[cfg(test)]
